# zeus-py

[![License: MIT](https://img.shields.io/badge/License-MIT-blue.svg)](https://opensource.org/licenses/MIT)
[![PyPi](https://img.shields.io/pypi/v/zeus-py)](https://pypi.org/project/zeus-py/)

## Description
zeus-py is a Python wrapper for the Zeus API. It provides a convenient way to interact with the Zeus platform using Python.

## Requirements
- Python 3.11.x or higher

## Installation
You can install zeus-py using pip:

```shell
py -3 -m pip install -U zeus-py
```


## Documentation
There is no documentation yet for this project